@@ -2,6 +2,7 @@
 #define _MAPSERVER_CONFIG_H
 
 #define USE_PROJ 1
+#define USE_PBF 1
 #define USE_POSTGIS 1
 #define USE_GDAL 1
 /* #undef USE_PIXMAN */
@@ -9,7 +10,7 @@
 #define USE_WMS_SVR 1
 #define USE_WCS_SVR 1
 #define USE_WFS_SVR 1
-/* #undef USE_SOS_SVR */
+#define USE_SOS_SVR 1
 #define USE_WFS_LYR 1
 #define USE_WMS_LYR 1
 #define USE_CURL 1
@@ -31,7 +32,7 @@
 /* #undef USE_EXEMPI */
 /* #undef USE_XMLMAPFILE */
 /* #undef USE_GENERIC_MS_NINT */
-/* #undef POSTGIS_HAS_SERVER_VERSION */
+#define POSTGIS_HAS_SERVER_VERSION 1
 /* #undef USE_SVG_CAIRO */
 /* #undef USE_RSVG */
 /* #undef USE_SDE */
@@ -49,7 +50,7 @@
 /* #undef HAVE_STRRSTR */
 #define HAVE_STRCASECMP 1
 #define HAVE_STRCASESTR 1
-#define HAVE_STRDUP 1
+/* #undef HAVE_STRDUP */
 #define HAVE_STRLCAT 1
 #define HAVE_STRLCPY 1
 #define HAVE_STRLEN 1
